JuliaRatinterp
JuliaRatinterp(julia_obj)Python wrapper for Julia rational interpolants.
Extends JuliaRatfun to include interpolation-specific functionality such as accessing interpolation nodes and values. This is the base class for specific interpolation methods like Thiele and Barycentric.
Attributes
| Name | Type | Description |
|---|---|---|
| julia | The underlying Julia rational interpolant object. |
Methods
| Name | Description |
|---|---|
| length | Get the number of interpolation points. |
| nodes | Get the interpolation nodes. |
| values | Get the interpolation values at the nodes. |
length
JuliaRatinterp.length()Get the number of interpolation points.
Returns
| Name | Type | Description |
|---|---|---|
| int | Number of nodes in the interpolant. |
nodes
JuliaRatinterp.nodes()Get the interpolation nodes.
Returns
| Name | Type | Description |
|---|---|---|
| np.ndarray: Array of interpolation node locations. |
values
JuliaRatinterp.values()Get the interpolation values at the nodes.
Returns
| Name | Type | Description |
|---|---|---|
| np.ndarray: Array of function values at interpolation nodes. |